@@ -3,7 +3,7 @@ package Task::Padre::Plugins;
 use warnings;
 use strict;
 
-our $VERSION = '0.10';
+our $VERSION = '0.12';
 
 1;
 __END__
@@ -32,10 +32,6 @@ Alarm Clock (Audio::Beep)
 
 vi and emacs in Padre?
 
-=head2 Padre::Plugin::CPAN
-
-CPAN in Padre
-
 =head3 Edit Config
 
 Edit CPAN/Config.pm
